==> uimaj-3.6.0-bin.zip: apache-uima/uimafit-core/api-change-report/japicmp.md <==

# Compatibility Report

![semver MINOR](https://img.shields.io/badge/semver-MINOR-orange?logo=semver "semver MINOR")

## Summary

> [!WARNING]
>
> Compatible changes found while checking backward compatibility of version `3.6.0` with the previous version `3.5.0`.

<details markdown="1">
<summary>Expand to see options used.</summary>

- **Report only summary**: No
- **Report only changes**: Yes
- **Report only binary-incompatible changes**: No
- **Access modifier filter**: `PROTECTED`
- **Old archives**:
  - ![uimafit-core 3.5.0](https://img.shields.io/badge/uimafit_core-3.5.0-blue "uimafit-core 3.5.0")
- **New archives**:
  - ![uimafit-core 3.6.0](https://img.shields.io/badge/uimafit_core-3.6.0-blue "uimafit-core 3.6.0")
- **Evaluate annotations**: Yes
- **Include synthetic classes and class members**: No
- **Include specific elements**: No
- **Exclude specific elements**: No
- **Ignore all missing classes**: No
- **Ignore specific missing classes**: Yes
  - `com\.strobel\..*`
  - `org\.apache\.logging\.log4j\..*`
- **Treat changes as errors**:
  - Any changes: No
  - Binary incompatible changes: No
  - Source incompatible changes: No
  - Incompatible changes caused by excluded classes: Yes
  - Semantically incompatible changes: No
  - Semantically incompatible changes, including development versions: No
- **Classpath mode**: `ONE_COMMON_CLASSPATH`
- **Old classpath**:
```

```
- **New classpath**:
```

```

</details>


## Results

| Status    | Type                                                      | Serialization       | Compatibility Changes |
|-----------|-----------------------------------------------------------|---------------------|-----------------------|
| Unchanged | [org.apache.uima.fit.factory.locator.JndiResourceLocator] | ![Not serializable] | ![Annotation deprecated added] |

<details markdown="1">
<summary>Expand for details.</summary>

___

<a id="user-content-org.apache.uima.fit.factory.locator.jndiresourcelocator"></a>
### `org.apache.uima.fit.factory.locator.JndiResourceLocator`

- [X] Binary-compatible
- [X] Source-compatible
- [X] Serialization-compatible

| Status    | Modifiers | Type  | Name                  | Extends               | JDK    | Serialization       | Compatibility Changes |
|-----------|-----------|-------|-----------------------|-----------------------|--------|---------------------|-----------------------|
| Unchanged | `public`  | Class | `JndiResourceLocator` | [`Resource_ImplBase`] | JDK 17 | ![Not serializable] | ![Annotation deprecated added] |


#### Annotations

| Status | Annotation         | Compatibility Changes |
|--------|--------------------|-----------------------|
| Added  | **[`Deprecated`]** | ![No changes]         |


</details>


> [!WARNING]
>
> Certain classes, i.e. superclasses and interfaces that could not be found on the classpath were ignored.
>
> Hence changes caused by these superclasses and interfaces are not reflected in the output.

___

*Generated on: 2024-11-22 17:43:05.054+0100*.

[Annotation deprecated added]: https://img.shields.io/badge/Annotation_deprecated_added-orange "Annotation deprecated added"
[No changes]: https://img.shields.io/badge/No_changes-green "No changes"
[Not serializable]: https://img.shields.io/badge/Not_serializable-green "Not serializable"
[`Deprecated`]: # "java.lang.Deprecated"
[`Resource_ImplBase`]: # "org.apache.uima.fit.component.Resource_ImplBase"
[org.apache.uima.fit.factory.locator.JndiResourceLocator]: #user-content-org.apache.uima.fit.factory.locator.jndiresourcelocator

==> uimaj-3.6.1-bin.zip: apache-uima/uimafit-core/api-change-report/japicmp.md <==

# Compatibility Report

![semver OK](https://img.shields.io/badge/semver-OK-green?logo=semver "semver OK")

## Summary

> [!NOTE]
>
> No incompatible changes found while checking backward compatibility of version `3.6.1` with the previous version `3.6.0`.

<details markdown="1">
<summary>Expand to see options used.</summary>

- **Report only summary**: No
- **Report only changes**: Yes
- **Report only binary-incompatible changes**: No
- **Access modifier filter**: `PROTECTED`
- **Old archives**:
  - ![uimafit-core 3.6.0](https://img.shields.io/badge/uimafit_core-3.6.0-blue "uimafit-core 3.6.0")
- **New archives**:
  - ![uimafit-core 3.6.1](https://img.shields.io/badge/uimafit_core-3.6.1-blue "uimafit-core 3.6.1")
- **Evaluate annotations**: Yes
- **Include synthetic classes and class members**: No
- **Include specific elements**: No
- **Exclude specific elements**: No
- **Ignore all missing classes**: No
- **Ignore specific missing classes**: Yes
  - `com\.strobel\..*`
  - `org\.apache\.logging\.log4j\..*`
- **Treat changes as errors**:
  - Any changes: No
  - Binary incompatible changes: No
  - Source incompatible changes: No
  - Incompatible changes caused by excluded classes: Yes
  - Semantically incompatible changes: No
  - Semantically incompatible changes, including development versions: No
- **Classpath mode**: `ONE_COMMON_CLASSPATH`
- **Old classpath**:
```

```
- **New classpath**:
```

```

</details>


> [!WARNING]
>
> Certain classes, i.e. superclasses and interfaces that could not be found on the classpath were ignored.
>
> Hence changes caused by these superclasses and interfaces are not reflected in the output.

___

*Generated on: 2025-09-24 12:01:38.871+0200*.
